NoOpPerformanceTracker class
Default PerformanceTracker — records nothing.
Used when no tracker is supplied, and in tests.
- Implemented types
Constructors
- NoOpPerformanceTracker()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startHttp(
{required Uri uri, required BifrostHttpMethod method}) → HttpTrace? -
Called immediately before
uriis requested.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited