SharedPrefService class
SharedPreferences implementation of StorageService.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> -
override
-
getBool(
String key) → bool -
Returns stored bool or
falseif key doesn't exist.override -
getInt(
String key) → int? -
override
-
getString(
String key) → String? -
override
-
getStringList(
String key) → List< String> ? -
override
-
init(
) → Future< void> -
Initialize the storage backend. Call before any read/write operations.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reload(
) → Future< void> -
override
-
remove(
String key) → Future< void> -
override
-
setBool(
String key, bool value) → Future< void> -
override
-
setInt(
String key, int value) → Future< void> -
override
-
setString(
String key, String value) → Future< void> -
override
-
setStringList(
String key, List< String> value) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited