BifrostInternalDiagnosticRecorder class final
Records repository-contained programming defects for test assertions.
Constructors
Properties
-
events
→ List<
BifrostInternalDiagnostic> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
BifrostInternalDiagnostic diagnostic) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited