MockConnectionChecker class

Configurable ConnectionChecker for online/offline test scenarios.

Implemented types

Constructors

MockConnectionChecker()

Properties

connected bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
Returns true if the device has network connectivity.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited