MockPaywallPresenter class
Records which placements were presented, and returns a scripted outcome.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outcome ↔ PaywallOutcome
-
getter/setter pair
-
presented
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
String placement) → Future< PaywallOutcome> -
Presents the paywall configured for
placementand waits for it to close.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited