MockStorage class

In-memory StorageService for unit and integration tests.

Implemented types

Constructors

MockStorage()

Properties

data Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringLists Map<String, List<String>>
final

Methods

clear() Future<void>
override
getBool(String key) bool
Returns stored bool or false if key doesn't exist.
override
getInt(String key) int?
override
getString(String key) String?
override
getStringList(String key) List<String>?
override
init() Future<void>
Initialize the storage backend. Call before any read/write operations.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() Future<void>
override
remove(String key) Future<void>
override
setBool(String key, bool value) Future<void>
override
setInt(String key, int value) Future<void>
override
setString(String key, String value) Future<void>
override
setStringList(String key, List<String> value) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited