BifrostTestEnv class
Shared Bifrost test dependencies and service locator wiring.
Reset before each test via reset (typically from flutter_test_config.dart):
setUp(bifrostTestEnv.reset);
Constructors
Properties
- analytics ↔ MockAnalyticsService
-
getter/setter pair
- attribution ↔ MockAttributionService
-
getter/setter pair
- connectionChecker ↔ MockConnectionChecker
-
getter/setter pair
- entitlements ↔ MockEntitlementService
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifier ↔ MockNotifier
-
getter/setter pair
- paywalls ↔ MockPaywallPresenter
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage ↔ MockStorage
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Fresh mocks and bifrostServiceLocator wiring for the current test.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited