MockAttributionService class
Configurable AttributionService. Defaults to null, matching iOS and an
organic Android install.
- Implemented types
Constructors
Properties
-
attributes
→ Map<
String, String?> -
final
- captureCount ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- referral ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureReferral(
) → Future< String?> -
Reads the install referral code, once, on first launch.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAttributes(
Map< String, String?> next) → Future<void> -
Attaches
attributesto the current subscriber so the billing vendor can segment revenue by them.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited