MockNotifier class
Tracks SystemNotifier callbacks for assertions in tests.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastBody ↔ String?
-
getter/setter pair
- lastStatusCode ↔ int?
-
getter/setter pair
- networkErrorCalled ↔ bool
-
getter/setter pair
- requestFailedCalled ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onNetworkError(
) → void -
No usable HTTP response (offline with no cache, transport error, etc.).
override
-
onRequestFailed(
{required int statusCode, String? body}) → void -
Any other non-success HTTP status (403, 4xx, 5xx).
override
-
HTTP 401 — session expired or not authenticated.
override
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited