TestDeviceDimensions enum
Device dimensions for golden tests.
Physical size is in pixels, dpi is the device pixel ratio. logicalSize is physicalSize / dpi.
Values
- iphone14PM → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(1290, 2796), 3) - iphoneSE → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(750, 1334), 2) - iphone13Mini → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(1080, 2340), 3) - pixel6 → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(1080, 2400), 2.625) - pixel7Pro → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(1440, 3120), 3.5) - ipadPro11 → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(1668, 2388), 2) - ipadPro12 → const TestDeviceDimensions
-
const TestDeviceDimensions(Size(2048, 2732), 2)
Properties
- dpi → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- logicalSize → Size
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TestDeviceDimensions> - A constant List of the values in this enum, in order of their declaration.